<?php
/**
 * new blog Theme Customizer
 *
 * @package glamour_magazine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function glamour_magazine_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'glamour_magazine_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'glamour_magazine_customize_partial_blogdescription',
		) );
	}
	//Upgrade to Pro
	// Register custom section types.
	$wp_customize->register_section_type( 'Glamour_Magazine_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Glamour_Magazine_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Go Pro', 'glamour-magazine' ),
				'pro_text' => esc_html__( 'Buy Pro Glamour Magazine', 'glamour-magazine' ),
				'pro_url'  => esc_url('https://www.postmagthemes.com/downloads/glamour-magazine-wordpress-theme/'),
				'priority' => 1,
			)
		)
	);
	$wp_customize->add_section(
		new Glamour_Magazine_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell2',
			array(
				'title'    => esc_html__( 'View', 'glamour-magazine' ),
				'pro_text' => esc_html__( 'All documents', 'glamour-magazine' ),
				'pro_url'  => esc_url('https://www.postmagthemes.com/docs/documentation-of-glamour-magazine-and-pro/'),
				'priority' => 2,
				'panel'          => 'glamour_magazine_document_panel',
			)
		)
	);
	$wp_customize->add_section(
		new Glamour_Magazine_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell3',
			array(
				'title'    => esc_html__( 'Text', 'glamour-magazine' ),
				'pro_text' => esc_html__( 'Setup post format', 'glamour-magazine' ),
				'pro_url'  => esc_url('https://www.postmagthemes.com/docs/documentation-of-glamour-magazine-and-pro/how-to-setup-post-formats-video-audio-gallery-quote-available-in-pro-version-only/'),
				'priority' => 3,
				'panel'          => 'glamour_magazine_document_panel',
			)
		)
	);
	$wp_customize->add_section(
		new Glamour_Magazine_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell4',
			array(
				'title'    => esc_html__( 'Text', 'glamour-magazine' ),
				'pro_text' => esc_html__( 'Introduction to sections', 'glamour-magazine' ),
				'pro_url'  => esc_url('https://www.postmagthemes.com/docs/documentation-of-glamour-magazine-and-pro/introduction-to-different-sections/'),
				'priority' => 4,
				'panel'          => 'glamour_magazine_document_panel',
			)
		)
	);

	$wp_customize->add_section(
		new Glamour_Magazine_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell6',
			array(
				'title'    => esc_html__( 'Video', 'glamour-magazine' ),
				'pro_text' => esc_html__( 'How to buy Pro theme', 'glamour-magazine' ),
				'pro_url'  => esc_url('https://www.youtube.com/watch?v=NUHM_qpu37Q'),
				'priority' => 6,
				'panel'          => 'glamour_magazine_document_panel',
			)
		)
	);
	
}
add_action( 'customize_register', 'glamour_magazine_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function glamour_magazine_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function glamour_magazine_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function glamour_magazine_customize_preview_js() {
	wp_enqueue_script( 'glamour-magazine-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'glamour_magazine_customize_preview_js' );
function glamour_magazine_customize_backend_scripts() {
	wp_enqueue_script( 'glamour_magazine-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/pro.js', array( 'customize-controls' ) );
	wp_enqueue_style( 'glamour_magazine-customize-controls', get_template_directory_uri() . '/inc/upgrade-to-pro/pro.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'glamour_magazine_customize_backend_scripts', 10 );


function glamour_magazine_customize_other( $wp_customize ) {
					// THEME OPTION panel  //
$wp_customize->add_panel( 'glamour_magazine_theme_option_panel', array(
	'priority'	=> 21,
	'title'		=> __( 'Theme options', 'glamour-magazine' )
) );
/**
     * Add Typography Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
		'glamour_magazine_document_panel',
		array(
			'priority'       => 2,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Documents', 'glamour-magazine' ),
		)
	);

				//////// 'Feature post section' //////////

$wp_customize->add_section( 'glamour_magazine_feature_post_section',
array(
	'title'      => __( 'Feature post section', 'glamour-magazine' ),
	'priority'   => 30,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

$wp_customize->add_setting( 'glamour_magazine_feature_post_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_feature_post_enable', 
	array(
		'label' 	=> __( 'Display feature post in blog homepage', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		'settings' 	=> 'glamour_magazine_feature_post_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_feature_post_inpage_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_feature_post_inpage_enable', 
	array(
		'label' 	=> __( 'Display feature post in page homepage', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		'settings' 	=> 'glamour_magazine_feature_post_inpage_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_feature_post_title', array(
	'capability'            => 'edit_theme_options',
	'default'               => __('Feature post','glamour-magazine'),
	'sanitize_callback'     => 'sanitize_text_field'
) );
$wp_customize->add_control( 'glamour_magazine_feature_post_title', array(
	'label'                 =>  __( 'Title', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_feature_post_section',
	'settings'              => 'glamour_magazine_feature_post_title',
	'type'					=> 'text',
) );
$wp_customize->add_setting( 'glamour_magazine_feature_post_order', 
array(
	
	'default'     => 'date',
	'sanitize_callback' => 'glamour_magazine_sanitize_select'
) );

$wp_customize->add_control( 'glamour_magazine_feature_post_order', 
	array(
		'label' 	=> __( 'Order by', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		'settings' 	=> 'glamour_magazine_feature_post_order',
		'type'      => 'select',
		'choices'	=> array (
			'date'	=> __( 'Recent publish date', 'glamour-magazine' ),
			'comment_count' => __( 'Most commented ', 'glamour-magazine' ),
			'rand'	=> __( 'Random', 'glamour-magazine' ),
		)

	) 
);

require_once( trailingslashit( get_template_directory() ) . 'inc/dropdown-category.php' );
$wp_customize->add_setting( 'glamour_magazine_feature_post_categorylist', 
array(
	'default'     => 0,
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Glamour_Magazine_My_Dropdown_Category_Control( $wp_customize, 'glamour_magazine_feature_post_categorylist', array(
	
		'label' 	=> __( 'Select the post among', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		
) 	)	
);
require_once( trailingslashit( get_template_directory() ) . 'inc/dropdown-author.php' );
$wp_customize->add_setting( 'glamour_magazine_feature_post_authorlist', 
array(
	'default'     =>  0,
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Glamour_Magazine_My_Dropdown_Author_Control( $wp_customize, 'glamour_magazine_feature_post_authorlist', array(
	
		'label' 	=> __( 'Select the post author', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		
) 	)	
);

$wp_customize->add_setting( 'glamour_magazine_feature_post_noofpost', 
array(
	'default'     => 3,
	'sanitize_callback' => 'glamour_magazine_sanitize_positive_integer'
) );

$wp_customize->add_control( 'glamour_magazine_feature_post_noofpost', 
	array(
		'label' 	=> __( 'Number of post to show', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_feature_post_section',
		'settings' 	=> 'glamour_magazine_feature_post_noofpost',
		'type' 		=> 'number',
	) 
);

$post_taxonomy_arrays = array(__('Category','glamour-magazine'));
foreach ($post_taxonomy_arrays as  $post_taxonomy) {
	$wp_customize->add_setting( 'glamour_magazine_feature_post_post_taxonomy_'.$post_taxonomy, array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'glamour_magazine_feature_post_post_taxonomy_'.$post_taxonomy, array(
		/* translators: %s: Label */ 
		'label'                 =>  sprintf( __( 'Display %s', 'glamour-magazine' ), $post_taxonomy ),
		'section'               => 'glamour_magazine_feature_post_section',
		'type'                  => 'checkbox',
		'settings' => 'glamour_magazine_feature_post_post_taxonomy_'.$post_taxonomy,

	) );
}
	
						///////   'Blog post section'  ////////////

$wp_customize->add_section( 'glamour_magazine_blog_post_section',
array(
	'title'      => __( 'Blog post section', 'glamour-magazine' ),
	'priority'   => 40,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

$wp_customize->add_setting( 'glamour_magazine_blog_post_enable', 
array(
	
	'default'     => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_blog_post_enable', 
	array(
		'label' 	=> __( 'Display blog post', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_blog_post_section',
		'settings' 	=> 'glamour_magazine_blog_post_enable',
		'type'      => 'checkbox',
		'description' => __('Below settings are applicable to archive and search page as well', 'glamour-magazine'),


	) 
);
$wp_customize->add_setting( 'glamour_magazine_blog_post_title', 
array(
	
	'default'     => '',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_blog_post_title', 
	array(
		'label' 	=> __( 'Display blog post title', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_blog_post_section',
		'settings' 	=> 'glamour_magazine_blog_post_title',
		'type'      => 'text',
	) 
);


$wp_customize->add_setting( 'glamour_magazine_blog_post_layout', 
array(
	'default'     => 2,
	'sanitize_callback' => 'glamour_magazine_sanitize_select'
) );

$wp_customize->add_control( 'glamour_magazine_blog_post_layout', 
	array(
		'label' 	=> __( 'Display type', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_blog_post_section',
		'settings' 	=> 'glamour_magazine_blog_post_layout',
		'type' 		=> 'select',
		'choices'	=> array(
		'2'			=> __('2 colume type','glamour-magazine')
		)
	) 
);
								///////   'Footer slider section'  ////////////

$wp_customize->add_section( 'glamour_magazine_footer_slider_section',
array(
	'title'      => __( 'Footer section', 'glamour-magazine' ),
	'priority'   => 60,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

$wp_customize->add_setting( 'glamour_magazine_footer_title', 
array(
	
	'default'     => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_footer_title', 
	array(
		'label' 	=> __( 'Display site title at footer', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_footer_slider_section',
		'settings' 	=> 'glamour_magazine_footer_title',
		'type'      => 'checkbox',

	) 
);

	// 'Social link' section
$wp_customize->add_section( 'glamour_magazine_section_social_section',
array(
	'title'      => __( 'Social link section', 'glamour-magazine' ),
	'priority'   => 70,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );
////	enable social link at variuos places  /////

$wp_customize->add_setting( 'glamour_magazine_social_top_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 0,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );
$wp_customize->add_control( 'glamour_magazine_social_top_enable', array(
	'label'                 =>  __( 'Enable social link at top', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_social_top_enable',
) );

$wp_customize->add_setting( 'glamour_magazine_social_sidebar_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 0,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );
$wp_customize->add_control( 'glamour_magazine_social_sidebar_enable', array(
	'label'                 =>  __( 'Enable social link at sidebar', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_social_sidebar_enable',
) );
$wp_customize->add_setting( 'glamour_magazine_social_sidebar_title', array(
	'capability'            => 'edit_theme_options',
	'default'               => __('Stay connected','glamour-magazine'),
	'sanitize_callback'     => 'sanitize_text_field'
) );
$wp_customize->add_control( 'glamour_magazine_social_sidebar_title', array(
	'label'                 =>  __( 'Title social link at sidebar', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'settings'              => 'glamour_magazine_social_sidebar_title',
	'type'					=> 'text',
) );
$wp_customize->add_setting( 'glamour_magazine_social_bottom_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 0,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );
$wp_customize->add_control( 'glamour_magazine_social_bottom_enable', array(
	'label'                 =>  __( 'Enable social link at bottom', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_social_bottom_enable',
) );


// Socail url
$social_name_arrays = array(__('Facebook','glamour-magazine'),__('Twitter','glamour-magazine'),__('Youtube','glamour-magazine'),__('Pinterest','glamour-magazine'),__('Instagram','glamour-magazine'));
foreach ($social_name_arrays as  $social_name) {
	$wp_customize->add_setting( 'glamour_magazine_social_url_'.$social_name, array(
	'capability'            => 'edit_theme_options',
	'default'               => '',
	'sanitize_callback' => 'glamour_magazine_sanitize_url'
	) );

	$wp_customize->add_control( 'glamour_magazine_social_url_'.$social_name, array(
		/* translators: %s: Label */ 
		'label'                 =>  sprintf( __( '%s Url', 'glamour-magazine' ), $social_name ),
		'section'               => 'glamour_magazine_section_social_section',
		'type'                  => 'url',
		'settings' => 'glamour_magazine_social_url_'.$social_name,
	) );
}
//Socail Url Enable or disable by checkboxs

$wp_customize->add_setting( 'glamour_magazine_facebook_url_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_facebook_url_enable', array(
	'label'                 =>  __( 'Enable facebook Icon', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_facebook_url_enable',
) );
$wp_customize->add_setting( 'glamour_magazine_twitter_url_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_twitter_url_enable', array(
	'label'                 =>  __( 'Enable Twitter icon', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_twitter_url_enable',
) );

$wp_customize->add_setting( 'glamour_magazine_youtube_url_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_youtube_url_enable', array(
	'label'                 =>  __( 'Enable YouTube Icon', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_youtube_url_enable',
) );

$wp_customize->add_setting( 'glamour_magazine_pinterest_url_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_pinterest_url_enable', array(
	'label'                 =>  __( 'Enable Pinterest Icon', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_pinterest_url_enable',
) );
$wp_customize->add_setting( 'glamour_magazine_instagram_url_enable', array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback'     => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_instagram_url_enable', array(
	'label'                 =>  __( 'Enable Instagram Icon', 'glamour-magazine' ),
	'section'               => 'glamour_magazine_section_social_section',
	'type'                  => 'checkbox',
	'settings'              => 'glamour_magazine_instagram_url_enable',
) );

	
//////   'Sidebar  section enable'  ////////////

$wp_customize->add_setting( 'glamour_magazine_sidebar_enable', 
array(
	
	'default'     => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_enable', 
	array(
		'label' 	=> __( 'Display sidebar at every post', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_enable_page', 
array(
	
	'default'     => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_enable_page', 
	array(
		'label' 	=> __( 'Display sidebar at every page', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_enable_page',
		'type'      => 'checkbox',

	) 
);
//////   'Sidebar about section'  ////////////

$wp_customize->add_setting( 'glamour_magazine_sidebar_about_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_about_enable', 
	array(
		'label' 	=> __( 'Display about', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_about_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_about_title', 
array(
	
	'default'     => __('About Me','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_about_title', 
	array(
		'label' 	=> __( 'Display about', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_about_title',
		'type'      => 'text',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_about_textarea', 
array(
	
	'default'     => __('Mauris eget pharetra lectus', 'glamour-magazine'),
	'sanitize_callback' => 'sanitize_textarea_field'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_about_textarea', 
	array(
		'label' 	=> __( 'Write about', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_about_textarea',
		'type'      => 'text',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_about_image', 
array(
	
	'default'     => '',
	'sanitize_callback' => 'sanitize_textarea_field'
) );
$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'logo',
		array(
			'label'      => __( 'Upload a image', 'glamour-magazine' ),
			'section'    => 'glamour_magazine_sidebar_section',
			'settings'   => 'glamour_magazine_sidebar_about_image',
			'context'    => 'your_setting_context' 
		)
	)
);

			///////   'Sidebar slider section'  ////////////

$wp_customize->add_section( 'glamour_magazine_sidebar_section',
array(
	'title'      => __( 'Sidebar section', 'glamour-magazine' ),
	'priority'   => 80,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

///////   'Sidebar post section'  ////////////

$wp_customize->add_setting( 'glamour_magazine_sidebar_post_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_post_enable', 
	array(
		'label' 	=> __( 'Display sidebar post', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_post_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_post_title', 
array(
	
	'default'     => __('Latest Posts','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_post_title', 
	array(
		'label' 	=> __( 'Display sidebar post', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_post_title',
		'type'      => 'text',

	) 
);

$wp_customize->add_setting( 'glamour_magazine_sidebar_post_order', 
array(
	
	'default'     => 'date',
	'sanitize_callback' => 'glamour_magazine_sanitize_select'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_post_order', 
	array(
		'label' 	=> __( 'Order by', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_post_order',
		'type'      => 'select',
		'choices'	=> array (
			'date'	=> __( 'Recent publish date', 'glamour-magazine' ),
			'comment_count' => __( 'Most commented ', 'glamour-magazine' ),
			'rand'	=> __( 'Random', 'glamour-magazine' ),

		)

	) 
);

require_once( trailingslashit( get_template_directory() ) . 'inc/dropdown-category.php' );
$wp_customize->add_setting( 'glamour_magazine_sidebar_post_categorylist', 
array(
	'default'     =>  0,
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Glamour_Magazine_My_Dropdown_Category_Control( $wp_customize, 'glamour_magazine_sidebar_post_categorylist', array(
	
		'label' 	=> __( 'Select the post among', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		
) 	)	
);
require_once( trailingslashit( get_template_directory() ) . 'inc/dropdown-author.php' );
$wp_customize->add_setting( 'glamour_magazine_sidebar_post_authorlist', 
array(
	'default'     =>  0,
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Glamour_Magazine_My_Dropdown_Author_Control( $wp_customize, 'glamour_magazine_sidebar_post_authorlist', array(
	
		'label' 	=> __( 'Select the post author', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		
) 	)	
);

$wp_customize->add_setting( 'glamour_magazine_sidebar_post_noofpost', 
array(
	'default'     => 4,
	'sanitize_callback' => 'glamour_magazine_sanitize_positive_integer'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_post_noofpost', 
	array(
		'label' 	=> __( 'Number of post to show', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_post_noofpost',
		'type' 		=> 'number',
	) 
);

$post_taxonomy_arrays = array(__('Date','glamour-magazine'), __('Image','glamour-magazine'));
foreach ($post_taxonomy_arrays as  $post_taxonomy) {
	$wp_customize->add_setting( 'glamour_magazine_sidebar_post_post_taxonomy_'.$post_taxonomy, array(
	'capability'            => 'edit_theme_options',
	'default'               => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'glamour_magazine_sidebar_post_post_taxonomy_'.$post_taxonomy, array(
		/* translators: %s: Label */ 
		'label'                 =>  sprintf( __( 'Display %s', 'glamour-magazine' ), $post_taxonomy ),
		'section'               => 'glamour_magazine_sidebar_section',
		'type'                  => 'checkbox',
		'settings' => 'glamour_magazine_sidebar_post_post_taxonomy_'.$post_taxonomy,

	) );
}

				//////   'Sidebar Quote section'  ////////////
$wp_customize->add_setting( 'glamour_magazine_sidebar_quote_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_quote_enable', 
	array(
		'label' 	=> __( 'Display quote', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_quote_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_quote_title', 
array(
	
	'default'     => __('Quotes Of The Day','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_quote_title', 
	array(
		'label' 	=> __( 'Display quote', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_quote_title',
		'type'      => 'text',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_sidebar_quote_textarea', 
array(
	
	'default'     => __('this is my quote','glamour-magazine'),
	'sanitize_callback' => 'sanitize_textarea_field'
) );

$wp_customize->add_control( 'glamour_magazine_sidebar_quote_textarea', 
	array(
		'label' 	=> __( 'Write about', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_sidebar_section',
		'settings' 	=> 'glamour_magazine_sidebar_quote_textarea',
		'type'      => 'text',

	) 
);
//////   'Single page section'  ////////////

$wp_customize->add_section( 'glamour_magazine_single_page_section',
array(
	'title'      => __( 'Single page section', 'glamour-magazine' ),
	'priority'   => 100,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

$wp_customize->add_setting( 'glamour_magazine_single_page_author_title', 
array(
	
	'default'     => __('Author','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_single_page_author_title', 
	array(
		'label' 	=> __( 'Author title', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_single_page_section',
		'settings' 	=> 'glamour_magazine_single_page_author_title',
		'type'      => 'text',

	) 
);
$post_taxonomy_arrays = array(__('Author section','glamour-magazine'),__('Avatar','glamour-magazine'), __('Email','glamour-magazine'),__('Description','glamour-magazine'));
foreach ($post_taxonomy_arrays as  $post_taxonomy) {
	$wp_customize->add_setting( 'glamour_magazine_single_page_post_taxonomy_'.$post_taxonomy, array(
	'capability'            => 'edit_theme_options',
	'default'               => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'glamour_magazine_single_page_post_taxonomy_'.$post_taxonomy, array(
		/* translators: %s: Label */ 
		'label'                 =>  sprintf( __( 'Display %s', 'glamour-magazine' ), $post_taxonomy ),
		'section'               => 'glamour_magazine_single_page_section',
		'type'                  => 'checkbox',
		'settings' => 'glamour_magazine_single_page_post_taxonomy_'.$post_taxonomy,

	) );
}

$wp_customize->add_setting( 'glamour_magazine_related_post_enable', 
array(
	
	'default'     => 0,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_related_post_enable', 
	array(
		'label' 	=> __( 'Display related post', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_single_page_section',
		'settings' 	=> 'glamour_magazine_related_post_enable',
		'type'      => 'checkbox',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_related_post_title', 
array(
	
	'default'     => __('Related Posts','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_related_post_title', 
	array(
		'label' 	=> __( 'Related post title', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_single_page_section',
		'settings' 	=> 'glamour_magazine_related_post_title',
		'type'      => 'text',

	) 
);
$wp_customize->add_setting( 'glamour_magazine_related_post_order', 
array(
	
	'default'     => 'date',
	'sanitize_callback' => 'glamour_magazine_sanitize_select'
) );

$wp_customize->add_control( 'glamour_magazine_related_post_order', 
	array(
		'label' 	=> __( 'Order by', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_single_page_section',
		'settings' 	=> 'glamour_magazine_related_post_order',
		'type'      => 'select',
		'choices'	=> array (
			'date'	=> __( 'Recent publish date', 'glamour-magazine' ),
			'comment_count' => __( 'Most commented ', 'glamour-magazine' ),
			'rand'	=> __( 'Random', 'glamour-magazine' ),

		)

	) 
);
$wp_customize->add_setting( 'glamour_magazine_related_post_noofpost', 
array(
	'default'     => 2,
	'sanitize_callback' => 'glamour_magazine_sanitize_positive_integer'
) );

$wp_customize->add_control( 'glamour_magazine_related_post_noofpost', 
	array(
		'label' 	=> __( 'Number of post to show', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_single_page_section',
		'settings' 	=> 'glamour_magazine_related_post_noofpost',
		'type' 		=> 'number',
	) 
);

///////// 'General setting section'  ////////////

$wp_customize->add_section( 'glamour_magazine_general_setting_section',
array(
	'title'      => __( 'General setting section', 'glamour-magazine' ),
	'priority'   => 110,
	'panel'		=> 'glamour_magazine_theme_option_panel'
) );

$wp_customize->add_setting( 'glamour_magazine_read_more_title', 
array(
	
	'default'     => __('Read more','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_read_more_title', 
	array(
		'label' 	=> __( 'Read more text', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_general_setting_section',
		'settings' 	=> 'glamour_magazine_read_more_title',
		'type'      => 'text',
	));
$wp_customize->add_setting( 'glamour_magazine_popup_enable', 
array(
	
	'default'     => 1,
	'sanitize_callback' => 'glamour_magazine_sanitize_checkbox'
) );

$wp_customize->add_control( 'glamour_magazine_popup_enable', 
	array(
		'label' 	=> __( 'Enable popup window for read more', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_general_setting_section',
		'settings' 	=> 'glamour_magazine_popup_enable',
		'type'      => 'checkbox',
));

$wp_customize->add_setting( 'glamour_magazine_close_title', 
array(
	
	'default'     => __('Close','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_close_title', 
	array(
		'label' 	=> __( 'Close at popup', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_general_setting_section',
		'settings' 	=> 'glamour_magazine_close_title',
		'type'      => 'text',
	));
$wp_customize->add_setting( 'glamour_magazine_detail_here_title', 
array(
	
	'default'     => __('Full view here','glamour-magazine'),
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'glamour_magazine_detail_here_title', 
	array(
		'label' 	=> __( 'Full view at popup', 'glamour-magazine' ),
		'section'	=> 'glamour_magazine_general_setting_section',
		'settings' 	=> 'glamour_magazine_detail_here_title',
		'type'      => 'text',
	));

}
add_action( 'customize_register', 'glamour_magazine_customize_other' );